function X = correlate_features (X, K, sigma2_noise)
% Creates KC correlated features from those in X, and adds
% gaussian noise with mean zero and variance sigma2_noise.
%
% Inputs:
%        - X (nsubject x nfeatures): feature matrix
%        - K (scalar): number of correlated features to generate
%        - sigma2_noise (scalar): variance of added noise
% Output:
%        - X (nsubject x (nfeatures + KC))
%
% J. Spilka, P. Abry, R. Leonarduzzi
% 2018

[nsub, nfeat] = size (X);

for k = 1 : K
    R = (X(:, fix (rand * nfeat) + 1) + X(:, fix (rand * nfeat) + 1)) / 2 + ...
        normrnd (0, sqrt (sigma2_noise), nsub, 1);
    X = [X R];
end
